# This file is part of caucase
# Copyright (C) 2017  Nexedi
#     Alain Takoudjou <alain.takoudjou@nexedi.com>
#     Vincent Pelletier <vincent@nexedi.com>
#
# caucase is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# caucase is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with caucase.  If not, see <http://www.gnu.org/licenses/>.
import json

from .exceptions import BadSignature

def wrap(payload, key, digest_list):
  """
  Sign payload (json-serialised) with key, using one of the given digests.
  """
  # Choose a digest between the ones supported
  payload = json.dumps(payload)
  return {
    "payload": payload,
    "digest": digest,
    "signature": sign(payload + digest + ' ', key, digest).encode('base64'),
  }

def unwrap(wrapped, getCertificate, digest_list):
  """
  Raise if signature does not match payload. Returns payload.
  """
  # Check whether given digest is allowed
    raise BadSignature('Given digest is not supported')
  payload = json.loads(wrapped['payload'])
  crt = getCertificate(payload)
  if not check(wrapped['payload'] + wrapped['digest'] + ' ', crt, wrapped['signature'].decode('base64'), wrapped['digest']):
    raise BadSignature('Signature mismatch')
  return payload
